/************************************************************************/
/*  MakeDatlog:
/*	Update serial numbers in datlog.NC.tbl file.
/************************************************************************/
/*
    Author:
	Stephane Zuzlewski
	UC Berkeley Seismological Laboratory
	stephane@seismo.berkeley.edu

    Purpose:

    Modification History:
    Date	Ver	Who	What
    ---------------------------------------------------------------------
    2003/11/26	1.0	SMZ	Initial coding.
    2004/06/10	1.0	SMZ	Put 'MULTI' for firmware_nb.
/************************************************************************/

#ifndef lint
static char sccsid[] = "%W% %G% %U%";
#endif

#include	<stdio.h>

#define		VERSION		"1.0"
#define		info		stdout

char *syntax[] = {
"%s version " VERSION " -- Update serial numbers in datlog.NC.tbl file.",
"%s  [-h] [-f file]",
"    where:",
"	-h	    Help - prints syntax message.",
"	-f <file>   Specifies the NCSN datalogger file.",
NULL };

/************************************************************************/

#include <string.h>


/************************************************************************/
/*  External variables and symbols.					*/
/************************************************************************/
char *cmdname;			/* program name from command line.	*/

/************************************************************************/
/*  print_syntax:							*/
/*	Print the syntax description of program.			*/
/************************************************************************/
int print_syntax
   (char	*cmd,		/* program name.			*/
    char	*syntax[],	/* syntax array.			*/
    FILE	*fp)		/* FILE ptr for output.			*/
{
    int i;
    for (i=0; syntax[i] != NULL; i++) {
	fprintf (fp, syntax[i], cmd);
	fprintf (fp, "\n");
    }
    return (0);
}

/************************************************************************/
/*  main:   main program.
/************************************************************************/
main (int	argc, char	*argv[])
{
 /* Variables needed for getopt. */
 extern char	*optarg;
 extern int	optind, opterr;
 int		c;
 char		*p;
 char	fname[255];
 FILE	*f;
 char	line[256];
 char	serialnb[81];
 char	header[16];
 char	type[32];
 char	firmnb[32];
 char	stime[32];
 char	etime[32];
 char	boardnb[32];
 char	modnb[32];
 int	Flag = 0;


 cmdname = ((p = strrchr(*argv,'/')) != NULL) ? ++p : *argv;
 /*	Parse command line options.					*/
 while ( (c = getopt(argc,argv,"hf:")) != -1) switch (c) {
	case '?':
	case 'h':	print_syntax(cmdname,syntax,info); exit(0); break;
	case 'f':	Flag = 1;strcpy (fname, optarg); break;
	default:	fprintf (info, "Unknown option: -%c\n", c); exit(1);
 }
 /*	Skip over all options and their arguments.			*/
 argv = &(argv[optind]);
 argc -= optind;

 if (Flag == 0)
	{
	 print_syntax(cmdname,syntax,info);
	 exit(0);
	}

 if ((f = fopen (fname, "rt")) == NULL)
	{
	 printf ("\n Error: couldn't open file %s.\n", fname);
	 exit (-1);
	}

 fgets (line, 255, f);
 while (!feof (f))
	{
	 sscanf (line, "%s", header);

	 if (!strcmp (header, "#"))
		{
		 /* Do nothing */
		}
	 else if (!strcmp (header, "DATLOG"))
		{
		 sscanf (line, "%*s %s %s %s %s %s %s",
			 type, serialnb, firmnb, stime, etime, boardnb);

		 printf ("DATLOG %s NC.%s.%s %s %s %s %s\n",
			 type, type, serialnb, "MULTI", stime, etime, boardnb);
		}
	 else if (!strcmp (header, "DM"))
		{
		 sscanf (line, "%*s %s %*s %s",
			 boardnb, modnb); 

		 printf ("DM %s NC.%s.%sP %s\n",
			 boardnb, type, serialnb, modnb);
		}
	 else if (!strcmp (header, "DMCS"))
		{
		 printf ("%s", line);
		}
	 else
		{
		 printf ("%s", line);
		}

	 fgets (line, 255, f);
	}

 fclose (f);

 return (0);
}
